from openmm.app import *
from openmm import *
from openmm.unit import *
from sys import stdout


pdb = PDBFile('1bna_2n_modified2.pdb')
forcefield = ForceField('amber14/tip3pfb.xml', 'DNA_mod_CG2.xml')  # point at the folder you copied the file DNA_mod_CG.xml in

modeller = Modeller(pdb.topology, pdb.positions)
modeller.addExtraParticles(forcefield)


system = forcefield.createSystem(pdb.topology, nonbondedMethod=PME,
        nonbondedCutoff=1*nanometer, constraints=HBonds)
integrator = LangevinMiddleIntegrator(300*kelvin, 1/picosecond, 0.002*picoseconds)
simulation = Simulation(pdb.topology, system, integrator)
simulation.context.setPositions(pdb.positions)
simulation.minimizeEnergy()
simulation.reporters.append(PDBReporter('output.pdb', 100))
simulation.reporters.append(StateDataReporter(stdout, 100, step=True,
        potentialEnergy=True, temperature=True))
simulation.step(1000)
